
{*******************************************************}
{                                                       }
{   Types et structures                                 }
{   du Novell 4.0 Pour Borland DELPHI                   }
{                                                       }
{   Convertion du C au PASCAL                           }
{   par Couery Tanguy le 26/11/95                       }
{                                                       }
{   Pour le projet Novell Netware de 3me anne         }
{   (BRETIN David,COUERY Tanguy,GUILHEM Eric)           }
{                                                       }
{                                                       }
{*******************************************************}

unit TIPXSPX;

interface

type
  PInteger  = ^Integer;
  PByte     = ^Byte;
  PWord     = ^Word;
  PLongInt  = ^LongInt;


type
PIPXAddress = ^IPXAddress;
IPXAddress = record
   network: array [0..3] of BYTE;
   node: array [0..5] of BYTE;
   socket: array [0..1] of BYTE;
end;

type
PIPXHeader = ^IPXHeader;
IPXHeader = record
   checkSum: WORD;
   length: WORD;
   transportControl: BYTE;
   packetType: BYTE;
   destination: IPXAddress;
   source: IPXAddress;
end;

type
PSPXHeader = ^SPXHeader;
SPXHeader = record
   checksum: WORD;
   length: WORD;
   transportControl: BYTE;
   packetType: BYTE;
   destination: IPXAddress;
   source: IPXAddress;
   connectionControl: BYTE;
   dataStreamType: BYTE;
   sourceConnectionID: WORD;
   destConnectionID: WORD;
   sequenceNumber: WORD;
   acknowledgeNumber: WORD;
   allocationNumber: WORD;
end;

type
PCONNECTION_INFO = ^CONNECTION_INFO;
CONNECTION_INFO = record
   connectionState: BYTE;
   connectionFlags: BYTE;
   sourceConnectionID: WORD;
   destinationConnectionID: WORD;
   sequenceNumber: WORD;
   acknowledgeNumber: WORD;
   allocationNumber: WORD;
   remoteAcknowledgeNumber: WORD;
   remoteAllocationNumber: WORD;
   connectionSocket: WORD;
   immediateAddress: array [0..5] of BYTE;
   destination: IPXAddress;
   retransmissionCount: WORD;
   estimatedRoundTripDelay: WORD;
   retransmittedPackets: WORD;
   suppressedPackets: WORD;
end;

type
PECBFragment = ^ECBFragment;
ECBFragment = record
   address: pointer;
   size: WORD;
end;

type
PECB = ^ECB;
ECB = record
   linkAddress: pointer;
   ESRAddress: pointer;
   inUseFlag: BYTE;
   completionCode: BYTE;
   socketNumber: WORD;
   IPXWorkspace: array [0..3] of BYTE;
   driverWorkspace: array [0..11] of BYTE;
   immediateAddress: array [0..5] of BYTE;
   fragmentCount: WORD;
   fragmentDescriptor: array [0..4] of ECBFragment;
end;

type
PAGLT = ^AGLT;
AGLT = record
   ecb: ECB;
   taskID: longint;
   retry: WORD;
   hWnd: word;
end;

type
PSAPHeader = ^SAPHeader;
SAPHeader = record
   checksum: WORD;
   length: WORD;
   transportControl: BYTE;
   packetType: BYTE;
   destination: IPXAddress;
   source: IPXAddress;
   SAPPacketType: WORD;
   serverType: WORD;
   serverName: array [0..47] of BYTE;
   serverAddress: IPXAddress;
   interveningNetworks: WORD;
end;

type
PSAPQueryPacket = ^SAPQueryPacket;
SAPQueryPacket = record
   checksum: WORD;
   length: WORD;
   transportControl: BYTE;
   packetType: BYTE;
   destination: IPXAddress;
   source: IPXAddress;
   queryType: WORD;
   serverType: WORD;
end;

type
PSAP_BUFFER = ^SAP_BUFFER;
SAP_BUFFER = record
   theECB: ECB;
   packet: SAPHeader;
end;

type
PSAP = ^SAP;
SAP = record
   Header: IPXHeader;
   ResponseType: WORD;
   ServerType: WORD;
   ServerName: array [0..47] of char;
   Network: array [0..3] of BYTE;
   Node: array [0..5] of BYTE;
   Socket: array [0..1] of BYTE;
   InterveningNetworks: WORD;
end;

type
PSEND_PACKET = ^SEND_PACKET;
SEND_PACKET = record
   theECB: ECB;
   SAPq: SAPQueryPacket;
end;

type
PRECEIVE_PACKET = ^RECEIVE_PACKET;
RECEIVE_PACKET = record
   theECB: ECB;
   SB: SAP;
end;

type
PIPXPacket = ^IPXPacket;
IPXPacket = record
   data: array [0..575 - sizeof(IPXHeader)] of BYTE;
end;

type
PSPXPacket = ^SPXPacket;
SPXPacket = record
   data: array [0..575 - sizeof(IPXHeader)] of BYTE;
end;

type
PExclusionListStruct = ^ExclusionListStruct;
ExclusionListStruct = record
   nodeAddress: array [0..5] of BYTE;
end;

type
PExclusionPacketStructure = ^ExclusionPacketStructure;
ExclusionPacketStructure = record
   numberOfExclusions: BYTE;
   structureArray: array [0..79] of ExclusionListStruct;
end;

type
PAddrStruct = ^AddrStruct;
AddrStruct = record
   network: array [0..3] of BYTE;
   node: array [0..5] of BYTE;
end;

type
PStructDriver = ^StructDriver;
StructDriver = record
   localNetworkType: BYTE;
   network: array [0..3] of BYTE;
   node: array [0..5] of BYTE;
end;

type
PBridgeStruct = ^BridgeStruct;
BridgeStruct = record
   numberOfNets: BYTE;
   bridge: array [0..3] of StructDriver;
end;

type
PNodeStruct = ^NodeStruct;
NodeStruct = record
   name: array [0..11] of char;
   target: IPXAddress;
   numberOfComponents: BYTE;
   componentID: array [0..12] of BYTE;
   bridgePtr: PBridgeStruct;
end;

type
Ppacket2 = ^packet2;
packet2 = record
   majorVersion: BYTE;
   minorVersion: BYTE;
   SPXDiagnosticSocket: WORD;
   numberOfComponents: BYTE;
   componentStructure: array [0..575-sizeof(IPXHeader) - sizeof(AddrStruct) - 5] of BYTE;
end;

type
PConfigurationResponseStruct = ^ConfigurationResponseStruct;
ConfigurationResponseStruct = record
   address: AddrStruct;
   packet: packet2;
end;

type
PAllResponseData = ^AllResponseData;
AllResponseData = record
   completionCode: BYTE;
   intervalMarker: longint;
end;

type
PIPXSPXVersion = ^IPXSPXVersion;
IPXSPXVersion = record
   IPXMajorVersion: BYTE;
   IPXMinorVersion: BYTE;
   SPXMajorVersion: BYTE;
   SPXMinorVersion: BYTE;
end;

type
PIPXStatisticsStruct = ^IPXStatisticsStruct;
IPXStatisticsStruct = record
   sendPacketCount: longint;
   malformedPacketCount: WORD;
   getECBRequestCount: longint;
   getECBFailureCount: longint;
   AESEventCount: longint;
   postponedAESEventCount: WORD;
   maxConfiguredSocketsCount: WORD;
   maxOpenSocketsCount: WORD;
   openSocketFailureCount: WORD;
   listenECBCount: longint;
   ECBCancelFailureCount: WORD;
   findRouteFailureCount: WORD;
end;

type
PSPXStatisticsStruct = ^SPXStatisticsStruct;
SPXStatisticsStruct = record
   maxConnectionsCount: WORD;
   maxUsedConnectionsCount: WORD;
   establishConnectionRequest: WORD;
   establishConnectionFailure: WORD;
   listenConnectionRequestCount: WORD;
   listenConnectionFailureCount: WORD;
   sendPacketCount: longint;
   windowChokeCount: longint;
   badSendPacketCount: WORD;
   sendFailureCount: WORD;
   abortConnectionCount: WORD;
   listenPacketCount: longint;
   badListenPacketCount: WORD;
   incomingPacketCount: longint;
   badIncomingPacketCount: WORD;
   suppressedPacketCount: WORD;
   noSessionListenECBCount: WORD;
   watchdogDestroySessionCount: WORD;
end;

type
PSendPacketsRequestStruct = ^SendPacketsRequestStruct;
SendPacketsRequestStruct = record
   target: IPXAddress;
   immediateAddress: array [0..5] of BYTE;
   numberOfPackets: WORD;
   timerTickInterval: BYTE;
   packetsPerTickInterval: BYTE;
   packetSize: WORD;
   changeSize: WORD;
end;

type
PSendPacketsResponseStruct = ^SendPacketsResponseStruct;
SendPacketsResponseStruct = record
   numberOfTransmitErrors: WORD;
end;

type
PStartCountingPacketsStruct = ^StartCountingPacketsStruct;
StartCountingPacketsStruct = record
   destinationSocket: WORD;
end;

type
PReturnReceivedPacketStruct = ^ReturnReceivedPacketStruct;
ReturnReceivedPacketStruct = record
   packetsReceived: WORD;
end;

type
Pstatus = ^status;
status = BYTE;

type
PBridgeDriverStatusStruct = ^BridgeDriverStatusStruct;
BridgeDriverStatusStruct = record
   LANBoard: array [0..3] of status;
end;

type
PDriverConfigurationStruct = ^DriverConfigurationStruct;
DriverConfigurationStruct = record
   networkAddress: array [0..3] of BYTE;
   nodeAddress: array [0..5] of BYTE;
   LANMode: BYTE;
   nodeAddressType: BYTE;
   maxDataSize: WORD;
   reserved1: WORD;
   reserved4: BYTE;
   transportTime: WORD;
   reserved2: array [0..10] of BYTE;
   majorVersion: BYTE;
   minorVersion: BYTE;
   ethernetFlagBits: BYTE;
   selectedConfiguration: BYTE;
   LANDescription: array [0..79] of BYTE;
   IOAddress1: WORD;
   IODecodeRange1: WORD;
   IOAddress2: WORD;
   IODecodeRange2: WORD;
   memoryAddress1: array [0..2] of BYTE;
   memoryDecodeRange1: WORD;
   memoryAddress2: array [0..2] of BYTE;
   memoryDecodeRange2: WORD;
   interruptIsUsed1: BYTE;
   interruptLine1: BYTE;
   interruptIsUsed2: BYTE;
   interruptLine2: BYTE;
   DMAIsUsed1: BYTE;
   DMALine1: BYTE;
   DMAIsUsed2: BYTE;
   DMALine2: BYTE;
   microChannelFlagBits: BYTE;
   reserved3: BYTE;
   textDescription: array [0..79] of BYTE;
end;

type
PDriverStatisticsStruct = ^DriverStatisticsStruct;
DriverStatisticsStruct = record
   driverVersion: array [0..1] of BYTE;
   statisticsVersion: array [0..1] of BYTE;
   totalTxPacketCount: longint;
   totalRxPacketCount: longint;
   noECBAvailableCount: WORD;
   packetTxTooBigCount: WORD;
   packetTxTooSmallCount: WORD;
   packetRxOverflowCount: WORD;
   packetRxTooBigCount: WORD;
   packetRxTooSmallCount: WORD;
   packetTxMiscErrorCount: WORD;
   packetRxMiscErrorCount: WORD;
   retryTxCount: WORD;
   checksumErrorCount: WORD;
   hardwareRxMismatchCount: WORD;
   numberOfCustomVariables: WORD;
   variableData: array [0..494] of BYTE;
end;

type
POSVersionStruct = ^OSVersionStruct;
OSVersionStruct = record
   machineID: BYTE;
   versionData: array [0..40] of BYTE;
end;

type
PShellStatisticsStruct = ^ShellStatisticsStruct;
ShellStatisticsStruct = record
   shellRequestsCount: longint;
   operatorAbortsCount: WORD;
   operatorRetriesCount: WORD;
   timeoutsCount: WORD;
   writeErrorCount: WORD;
   invalidReplyHeaderCount: WORD;
   invalidSlotCount: WORD;
   invalidSequenceNumberCount: WORD;
   errorReceivingCount: WORD;
   noRouterFoundCount: WORD;
   beingProcessedCount: WORD;
   unknownErrorCount: WORD;
   invalidServerSlotCount: WORD;
   networkGoneCount: WORD;
   reserved1: WORD;
   allocateCannotFindRouteCount: WORD;
   allocateNoSlotsAvailableCount: WORD;
   allocateServerIsDownCount: WORD;
end;

type
PAddressTableStruct = ^AddressTableStruct;
AddressTableStruct = record
   serverUsed: BYTE;
   orderNumber: BYTE;
   serverNetwork: array [0..3] of BYTE;
   serverNode: array [0..5] of BYTE;
   serverSocket: WORD;
   receivedTimeOut: WORD;
   immediateNode: array [0..5] of BYTE;
   sequenceNumber: BYTE;
   connectionNumber: BYTE;
   connectionOK: BYTE;
   maximumTimeOut: WORD;
   reserved: array [0..4] of BYTE;
end;

type
PServerAddressTableStruct = ^ServerAddressTableStruct;
ServerAddressTableStruct = record
   addressTable: array [0..7] of AddressTableStruct;
end;

type
PNameTableStruct = ^NameTableStruct;
NameTableStruct = record
   name: array [0..47] of BYTE;
end;

type
PServerNameTableStruct = ^ServerNameTableStruct;
ServerNameTableStruct = record
   nameTable: array [0..7] of NameTableStruct;
end;

type
PPrimaryServerStruct = ^PrimaryServerStruct;
PrimaryServerStruct = record
   number: BYTE;
end;

type
PShellVersionStruct = ^ShellVersionStruct;
ShellVersionStruct = record
   minor: BYTE;
   major: BYTE;
   rev: BYTE;
end;

type
PBridgeStatisticsStruct = ^BridgeStatisticsStruct;
BridgeStatisticsStruct = record
   tooManyHopsCount: WORD;
   unknownNetworkCount: WORD;
   noSpaceForServiceCount: WORD;
   noReceiveBuffersCount: WORD;
   notMyNetwork: WORD;
   netBIOSPropogateCount: longint;
   totalPacketsServiced: longint;
   totalPacketsRouted: longint;
end;

type
PNumberStruct = ^NumberStruct;
NumberStruct = record
   number: array [0..3] of BYTE;
end;

type
PNodeAddressStruct = ^NodeAddressStruct;
NodeAddressStruct = record
   address: array [0..5] of BYTE;
   reserved: array [0..1] of BYTE;
end;

type
PLocalTablesStruct = ^LocalTablesStruct;
LocalTablesStruct = record
   localNetworkNumber: array [0..15] of NumberStruct;
   localNodeAddress: array [0..15] of NodeAddressStruct;
end;

type
PNetworkAddressStruct = ^NetworkAddressStruct;
NetworkAddressStruct = record
   address: array [0..3] of BYTE;
end;

type
PAllKnownNetworksStruct = ^AllKnownNetworksStruct;
AllKnownNetworksStruct = record
   numberOfNetworkAddresses: WORD;
   networkAddress: array [0..127] of NetworkAddressStruct;
end;

type
PRoutingInfoStruct = ^RoutingInfoStruct;
RoutingInfoStruct = record
   routerForwardingAddress: array [0..5] of BYTE;
   routerBoardNumber: BYTE;
   reserved: array [0..1] of BYTE;
   routeHops: BYTE;
   routeTime: WORD;
end;

type
PSpecificNetworkInfoStruct = ^SpecificNetworkInfoStruct;
SpecificNetworkInfoStruct = record
   networkAddress: array [0..3] of BYTE;
   hopsToNet: BYTE;
   reservedA: array [0..6] of BYTE;
   routeTimeToNet: WORD;
   numberOfKnownRouters: WORD;
   routingInfo: array [0..46] of RoutingInfoStruct;
end;

type
PServerInfoStruct = ^ServerInfoStruct;
ServerInfoStruct = record
   serverType: WORD;
   serverName: array [0..47] of BYTE;
end;

type
PAllKnownServersStruct = ^AllKnownServersStruct;
AllKnownServersStruct = record
   numberOfServers: WORD;
   serverInfo: array [0..9] of ServerInfoStruct;
end;

type
PRouteSourceInfoStruct = ^RouteSourceInfoStruct;
RouteSourceInfoStruct = record
   routeSourceAddress: array [0..5] of BYTE;
   routeHopsToSource: WORD;
   reserved: array [0..1] of BYTE;
end;

type
PSpecificServerInfoStruct = ^SpecificServerInfoStruct;
SpecificServerInfoStruct = record
   serverInfo: ServerInfoStruct;
   serverAddress: array [0..11] of BYTE;
   hopsToServer: WORD;
   reserved1: array [0..1] of BYTE;
   numberOfRoutes: WORD;
   routeSourceInfo: array [0..46] of RouteSourceInfoStruct;
end;

type
PConnectionStatusBlock = ^ConnectionStatusBlock;
ConnectionStatusBlock = record
   connectionState: BYTE;
   connectionFlags: BYTE;
   sourceConnectionID: array [0..1] of BYTE;
   destinationConnectionID: array [0..1] of BYTE;
   sequenceNumber: array [0..1] of BYTE;
   acknowledgeNumber: array [0..1] of BYTE;
   allocationNumber: array [0..1] of BYTE;
   remoteAcknowledgeNumber: array [0..1] of BYTE;
   remoteAllocationNumber: array [0..1] of BYTE;
   connectionSocket: WORD;
   immediateAddress: array [0..5] of BYTE;
   destination: IPXAddress;
   retransmissionCount: array [0..1] of BYTE;
   estimatedRoundTripDelay: array [0..1] of BYTE;
   retransmittedPackets: array [0..1] of BYTE;
   suppressedPackets: array [0..1] of BYTE;
end;

type
PNLServerInfoStruct = ^NLServerInfoStruct;
NLServerInfoStruct = record
   StructVersion: WORD;
   WorkgroupName: array [0..15] of BYTE;
   WorkgroupID: longint;
   ServerName: array [0..15] of BYTE;
   ServerID: longint;
   OEMString: array [0..15] of BYTE;
   OEMID: WORD;
   MajorVersion: BYTE;
   MinorVersion: BYTE;
   BetaVersion: BYTE;
   StartMinutes: BYTE;
   StartHours: BYTE;
   StartSeconds: BYTE;
   StartYear: WORD;
   StartDay: BYTE;
   StartMonth: BYTE;
   ServerAddressType: BYTE;
   ServerNetAddr: array [0..3] of BYTE;
   ServerNodeAddr: array [0..5] of BYTE;
   ServerSocket: array [0..1] of BYTE;
   ServerDescription: array [0..49] of BYTE;
   CfgConnections: WORD;
   CfgOpenFiles: WORD;
   CfgClientTasks: WORD;
   CfgDirBuffers: WORD;
   CfgServiceExtensions: WORD;
   CurServiceExtensions: WORD;
   CfgResources: WORD;
   CurResources: WORD;
   CfgDirs: WORD;
   CurDirs: WORD;
   CfgPrns: WORD;
   CurPrns: BYTE;
   SizePrintBuffers: WORD;
   NumReceiveBuffers: WORD;
   RealSizeReceiveBuffers: WORD;
   SizeReceiveBuffers: WORD;
   NumIOBuffers: WORD;
   SizeIOBuffers: WORD;
   ServerTSRSize: WORD;
   AuditingFlag: BYTE;
   ServerFlags: BYTE;
   OperatingSystem: BYTE;
   DosMajorVersion: BYTE;
   DosMinorVersion: BYTE;
   IsShareLoaded: BYTE;
   ServerLoadType: BYTE;
   ModuleFlag: longint;
   ScheduleControl: longint;
   ServerDiskVector: longint;
   RemovableDiskVector: longint;
end;

type
PNLServerStatsStruct = ^NLServerStatsStruct;
NLServerStatsStruct = record
   TotalPacketsReceived: longint;
   BadPackets: WORD;
   PacketsNotProcessedImmediately: WORD;
   LostResponses: WORD;
   PeakConnectionsUsed: WORD;
   PeakOpenFiles: WORD;
   PeakClientTasks: WORD;
   WatchdogPacketsSent: WORD;
   ClientsWatchdogged: WORD;
   ECBRepostsWithNoBuffers: WORD;
   SendPacketWithECBActive: WORD;
   TotalSlistRequests: WORD;
   ServerBusyPackets: WORD;
   ServerBusyPacketsNoBuffers: WORD;
   UnknownRequests: WORD;
   WriteBehindMisses: WORD;
   ReadCacheHits: longint;
   ReadCacheMisses: longint;
   ReadsTooLarge: WORD;
   CriticalErrors: WORD;
   SavedLargeDOSArea: longint;
   SavedSmallDOSArea: longint;
   StarvationCounter: WORD;
   WriteBehindHits: WORD;
   CacheBlocksInUse: WORD;
   Reserved: longint;
   PacketQueueRuns: longint;
   IdleLoopWaitHits: longint;
   Int21NotOurs: longint;
   TotalInt21Calls: longint;
   PasswordFailures: WORD;
   Reserved0: WORD;
end;

type
PNLServerCurrentStateStruct = ^NLServerCurrentStateStruct;
NLServerCurrentStateStruct = record
   CurConnections: WORD;
   CurOpenFiles: WORD;
   CurClientTasks: WORD;
   CurNumFreeBuffers: WORD;
   CurNumSemaphores: WORD;
end;

type
PNLCacheStatsStruct = ^NLCacheStatsStruct;
NLCacheStatsStruct = record
   NLCacheMajorVersion: BYTE;
   NLCacheMinorVersion: BYTE;
   TypeOfMemory: WORD;
   ReadRequests: longint;
   ActualReadsToDisk: longint;
   WriteRequests: longint;
   ActualWritesToDisk: longint;
   NumberOfDiskErrors: WORD;
   NumberOfMemoryErrors: WORD;
   CurrentSizeInElements: WORD;
   MaxNumElements: WORD;
   ElementSize: WORD;
   MinNumElements: WORD;
end;

type
PResponderTypeStruct = ^ResponderTypeStruct;
ResponderTypeStruct = record
   ResponderType: WORD;
   ResponderMajorVersion: BYTE;
   ResponderMinorVersion: BYTE;
end;

type
PGNMAQueryRequestStruct = ^GNMAQueryRequestStruct;
GNMAQueryRequestStruct = record
   ComponentIDIndex: BYTE;
   RequestType: BYTE;
   ResponderType: WORD;
   ResponderRequest: WORD;
   OtherData: WORD;
end;

type
PGNMAInfoStruct = ^GNMAInfoStruct;
GNMAInfoStruct = record
   GNMAMajorVersion: BYTE;
   GNMAMinorVersion: BYTE;
   GNMANumberOfResponders: WORD;
   _Type: array [0..130] of ResponderTypeStruct;
end;

type
PMachineStaticInfoStruct = ^MachineStaticInfoStruct;
MachineStaticInfoStruct = record
   StartDate: longint;
   StartTime: longint;
   OSVerMajor: BYTE;
   OSVerMinor: BYTE;
   OSVersionType: WORD;
   NumberOfSerialPorts: BYTE;
   NumberOfParallelPorts: BYTE;
   FloppyDriveCount: BYTE;
   FloppyDriveType: WORD;
   HardDriveCount: BYTE;
   KeyboardType: BYTE;
   BootVideoType: BYTE;
   DisplayMemory: longint;
   MathCoprocessor: BYTE;
   CoprocessorType: BYTE;
   CPUType: BYTE;
   Reserved: BYTE;
   ModelType: BYTE;
   SerialAddress: array [0..3] of WORD;
   ParallelAddress: array [0..3] of WORD;
   PointerDevice: BYTE;
   SystemMemory: WORD;
   MemoryTypes: BYTE;
   BIOSType: BYTE;
   BIOSRev: array [0..1] of BYTE;
   EISA_MCASlots: BYTE;
   EISA_MCAIRQ: array [0..15] of BYTE;
   EISA_CardName: BYTE;
   BusType: BYTE;
   HardDriveType: array [0..3] of BYTE;
   MemTypeFlag: BYTE;
   TotalXMS: WORD;
   AvailableXMS: WORD;
   TotalEMS: WORD;
   AvailableEMS: WORD;
   Reserved0: array [0..21] of BYTE;
end;

type
PNonremoveableDrivesStruct = ^NonremoveableDrivesStruct;
NonremoveableDrivesStruct = record
   DriveNumber: BYTE;
   SectorsPerCluster: longint;
   TotalNumberOfClustersPerDrive: longint;
   NumberOfAvailableClusters: longint;
   BytesPerSector: WORD;
end;

type
PMachineDynamicInfoStruct = ^MachineDynamicInfoStruct;
MachineDynamicInfoStruct = record
   CurrentDate: longint;
   CurrentTime: longint;
   MouseDriver: BYTE;
   Reserved: array [0..36] of BYTE;
   NonremoveableDriveCount: BYTE;
   Drive: array [0..30] of NonremoveableDrivesStruct;
end;

type
PPStackIDStruct = ^PStackIDStruct;
PStackIDStruct = record
   StackId: WORD;
   Name: array [0..17] of BYTE;
end;

type
PProtocolStackListStruct = ^ProtocolStackListStruct;
ProtocolStackListStruct = record
   NumberOfStacks: BYTE;
   PSID: array [0..19] of PStackIDStruct;
end;

type
PProtocolStackConfigStruct = ^ProtocolStackConfigStruct;
ProtocolStackConfigStruct = record
   ConfigMajorVersion: BYTE;
   ConfigMinorVersion: BYTE;
   ProtocolLongName: array [0..41] of BYTE;
   ProtocolShortName: array [0..16] of BYTE;
   StackMajorVersion: BYTE;
   StackMinorVersion: BYTE;
   Reserved: array [0..15] of BYTE;
end;

type
PProtocolStackStatsStruct = ^ProtocolStackStatsStruct;
ProtocolStackStatsStruct = record
   StatMajorVersion: BYTE;
   StatMinorVersion: BYTE;
   GenericCounters: WORD;
   ValidCountersMask: longint;
   TotalTxPackets: longint;
   TotalRxPackets: longint;
   IgnoredRxPackets: longint;
   OtherData: array [0..507] of BYTE;
end;

type
PMLIDIDStruct = ^MLIDIDStruct;
MLIDIDStruct = record
   MLIDId: WORD;
   Name: array [0..17] of BYTE;
end;

type
PMLIDListStruct = ^MLIDListStruct;
MLIDListStruct = record
   NumberOfMLIDs: BYTE;
   MLID: array [0..19] of MLIDIDStruct;
end;

type
PMLIDConfigurationStruct = ^MLIDConfigurationStruct;
MLIDConfigurationStruct = record
   Signature: array [0..25] of BYTE;
   ConfigTableMajorVersion: BYTE;
   ConfigTableMinorVersion: BYTE;
   NodeAddress: array [0..5] of BYTE;
   ModeFlags: WORD;
   BoardNumber: WORD;
   BoardInstance: WORD;
   MaxPacketSize: WORD;
   BestDataSize: WORD;
   WorstDataSize: WORD;
   NICLongName: array [0..41] of BYTE;
   NICShortName: array [0..9] of BYTE;
   FrameTypeString: array [0..41] of BYTE;
   Reserved: WORD;
   FrameTypeID: WORD;
   TransportTime: WORD;
   SourceRouteHandler: longint;
   LookAheadSize: WORD;
   LineSpeed: WORD;
   QueueDepth: WORD;
   Reserved0: array [0..5] of BYTE;
   DriverMajorVersion: BYTE;
   DriverMinorVersion: BYTE;
   Flags: array [0..1] of BYTE;
   SendRetries: WORD;
   ConfigTableLink: longint;
   SharingFlags: array [0..1] of BYTE;
   Slot: WORD;
   IOAddress1: WORD;
   IORange1: WORD;
   IOAddress2: WORD;
   IORange2: WORD;
   MemoryAddress1: longint;
   MemorySize1: WORD;
   MemoryAddress2: longint;
   MemorySize2: WORD;
   IntLine1: BYTE;
   IntLine2: BYTE;
   DMALine1: BYTE;
   DMALine2: BYTE;
   OtherData: array [0..327] of BYTE;
end;

type
PMLIDStatisticsStruct = ^MLIDStatisticsStruct;
MLIDStatisticsStruct = record
   DriverStatMajorVersion: BYTE;
   DriverStatMinorVersion: BYTE;
   NumberGenericCounters: WORD;
   ValidCountersMask: longint;
   TotalTxRequest: longint;
   TotalRxRequest: longint;
   NoECBAvailableCount: longint;
   TooBigTxRequest: longint;
   TooSmallTxRequest: longint;
   RxOverflowCount: longint;
   RxTooBigCount: longint;
   RxTooSmallCount: longint;
   TxMiscCount: longint;
   RxMiscCount: longint;
   TxRetryCount: longint;
   RxChecksumErrorCount: longint;
   RxMismatchCount: longint;
   OtherData: array [0..467] of BYTE;
end;

type
PLSLStatisticsStruct = ^LSLStatisticsStruct;
LSLStatisticsStruct = record
   StatMajorVersion: BYTE;
   StatMinorVersion: BYTE;
   GenericCounters: WORD;
   ValidCountersMask: longint;
   TotalTxPackets: longint;
   GetECBRequests: longint;
   GetECBFailures: longint;
   AESEventsCount: longint;
   PostponedEvents: longint;
   CancelAESFailures: longint;
   Reserved0: longint;
   Reserved1: longint;
   TotalRxPackets: longint;
   UnclaimedPackets: longint;
   OtherData: array [0..479] of BYTE;
end;

type
PLSLConfigurationStruct = ^LSLConfigurationStruct;
LSLConfigurationStruct = record
   ConfigMajorVersion: BYTE;
   ConfigMinorVersion: BYTE;
   Reserved: longint;
   Reserved0: longint;
   LSLMajorVersion: BYTE;
   LSLMinorVersion: BYTE;
   MaxBoardsNumber: WORD;
   MaxStacksNumber: WORD;
   Reserved1: array [0..11] of BYTE;
end;

type
PLSLNetCfgPathStruct = ^LSLNetCfgPathStruct;
LSLNetCfgPathStruct = record
   NetCfgPath: array [0..127] of BYTE;
end;

implementation

end.
